@@ -4,7 +4,7 @@ use crate::serialize::error::SerializeError;
 use crate::serialize::per_type::dict::ZeroDictSerializer;
 use crate::serialize::serializer::PyObjectSerializer;
 use crate::serialize::state::SerializerState;
-use crate::str::unicode_to_str;
+use crate::str::PyStr;
 use crate::typeref::{
     DATACLASS_FIELDS_STR, DICT_STR, FIELD_TYPE, FIELD_TYPE_STR, SLOTS_STR, STR_TYPE,
 };
@@ -15,7 +15,7 @@ use serde::ser::{Serialize, SerializeMap, Serializer};
 use core::ptr::NonNull;
 
 #[repr(transparent)]
-pub struct DataclassGenericSerializer<'a> {
+pub(crate) struct DataclassGenericSerializer<'a> {
     previous: &'a PyObjectSerializer,
 }
 
@@ -25,7 +25,7 @@ impl<'a> DataclassGenericSerializer<'a> {
     }
 }
 
-impl<'a> Serialize for DataclassGenericSerializer<'a> {
+impl Serialize for DataclassGenericSerializer<'_> {
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
@@ -63,7 +63,7 @@ impl<'a> Serialize for DataclassGenericSerializer<'a> {
     }
 }
 
-pub struct DataclassFastSerializer {
+pub(crate) struct DataclassFastSerializer {
     ptr: *mut pyo3_ffi::PyObject,
     state: SerializerState,
     default: Option<NonNull<pyo3_ffi::PyObject>>,
@@ -112,11 +112,10 @@ impl Serialize for DataclassFastSerializer {
                 if unlikely!(!is_class_by_type!(key_ob_type, STR_TYPE)) {
                     err!(SerializeError::KeyMustBeStr)
                 }
-                let tmp = unicode_to_str(key);
-                if unlikely!(tmp.is_none()) {
-                    err!(SerializeError::InvalidStr)
+                match unsafe { PyStr::from_ptr_unchecked(key).to_str() } {
+                    Some(uni) => uni,
+                    None => err!(SerializeError::InvalidStr),
                 }
-                tmp.unwrap()
             };
             if unlikely!(key_as_str.as_bytes()[0] == b'_') {
                 continue;
@@ -129,7 +128,7 @@ impl Serialize for DataclassFastSerializer {
     }
 }
 
-pub struct DataclassFallbackSerializer {
+pub(crate) struct DataclassFallbackSerializer {
     ptr: *mut pyo3_ffi::PyObject,
     state: SerializerState,
     default: Option<NonNull<pyo3_ffi::PyObject>>,
@@ -184,12 +183,9 @@ impl Serialize for DataclassFallbackSerializer {
                 continue;
             }
 
-            let key_as_str = {
-                let tmp = unicode_to_str(attr);
-                if unlikely!(tmp.is_none()) {
-                    err!(SerializeError::InvalidStr)
-                }
-                tmp.unwrap()
+            let key_as_str = match unsafe { PyStr::from_ptr_unchecked(attr).to_str() } {
+                Some(uni) => uni,
+                None => err!(SerializeError::InvalidStr),
             };
             if key_as_str.as_bytes()[0] == b'_' {
                 continue;
