@@ -2,14 +2,14 @@
 
 use crate::ffi::{Fragment, PyBytes_AS_STRING, PyBytes_GET_SIZE};
 use crate::serialize::error::SerializeError;
-use crate::str::unicode_to_str;
+use crate::str::PyStr;
 use crate::typeref::{BYTES_TYPE, STR_TYPE};
 use crate::util::isize_to_usize;
 
 use serde::ser::{Serialize, Serializer};
 
 #[repr(transparent)]
-pub struct FragmentSerializer {
+pub(crate) struct FragmentSerializer {
     ptr: *mut pyo3_ffi::PyObject,
 }
 
@@ -37,11 +37,10 @@ impl Serialize for FragmentSerializer {
                     isize_to_usize(PyBytes_GET_SIZE((*fragment).contents)),
                 );
             } else if core::ptr::eq(ob_type, STR_TYPE) {
-                let uni = unicode_to_str((*fragment).contents);
-                if unlikely!(uni.is_none()) {
-                    err!(SerializeError::InvalidStr)
+                match unsafe { PyStr::from_ptr_unchecked((*fragment).contents).to_str() } {
+                    Some(uni) => buffer = uni.as_bytes(),
+                    None => err!(SerializeError::InvalidStr),
                 }
-                buffer = uni.unwrap().as_bytes();
             } else {
                 err!(SerializeError::InvalidFragment)
             }
