@@ -2,11 +2,11 @@
 
 use serde::ser::{Serialize, Serializer};
 
-pub struct NoneSerializer;
+pub(crate) struct NoneSerializer;
 
 impl NoneSerializer {
-    pub fn new() -> Self {
-        NoneSerializer {}
+    pub const fn new() -> Self {
+        Self {}
     }
 }
 
