@@ -5,7 +5,7 @@ use crate::str::pyunicode_new::{
 };
 
 #[inline(never)]
-pub fn str_impl_kind_scalar(buf: &str) -> *mut pyo3_ffi::PyObject {
+pub(crate) unsafe fn str_impl_kind_scalar(buf: &str) -> *mut pyo3_ffi::PyObject {
     let num_chars = bytecount::num_chars(buf.as_bytes());
     if buf.len() == num_chars {
         return pyunicode_ascii(buf.as_ptr(), num_chars);
@@ -35,15 +35,3 @@ pub fn str_impl_kind_scalar(buf: &str) -> *mut pyo3_ffi::PyObject {
         }
     }
 }
-
-#[cfg(not(feature = "avx512"))]
-#[inline(always)]
-pub fn unicode_from_str(buf: &str) -> *mut pyo3_ffi::PyObject {
-    if unlikely!(buf.is_empty()) {
-        return use_immortal!(crate::typeref::EMPTY_UNICODE);
-    }
-    str_impl_kind_scalar(buf)
-}
-
-#[cfg(not(feature = "avx512"))]
-pub fn set_str_create_fn() {}
